@@ -89,6 +89,7 @@ class WbApp(wx.App):
 
         # init the locale
         self.initLocale()
+        self._setlocale_value = locale.getlocale()
 
         if sys.platform == 'win32':
             languages = [locale.getdefaultlocale()[0]]
@@ -129,6 +130,7 @@ class WbApp(wx.App):
         self.log.info( 'languages %s' % (languages,) )
         self.log.info( 'find %r' % (gettext.find( 'pysvn_workbench', locale_path, languages, all=1 ),) )
         self.log.info( 'info %r' % (self.translation.info(),) )
+        self.log.info( 'main thread is %r' % (self.main_thread,) )
 
         self.log.info( T_('PySVN WorkBench') )
 
@@ -152,7 +154,7 @@ class WbApp(wx.App):
 
         self.__paste_data = None
 
-        self.background_thread = wb_background_thread.BackgroundThread()
+        self.background_thread = wb_background_thread.BackgroundThread( self )
         self.background_thread.start()
 
         wx.App.__init__( self, 0 )
