@@ -43,7 +43,7 @@ if stdout_filename is not None:
 # make sure that we get 2.8 and not an earlier version
 try:
     import wxversion
-    wxversion.select( ['2.9'] )
+    wxversion.select( ['3.0', '2.9', '2.8'] )
 
 except:
     pass
@@ -70,9 +70,6 @@ def main( args ):
         if os.environ.has_key( envvar ):
             del os.environ[ envvar ]
 
-    # init the locale
-    initLocale()
-
     # Register all supported source control providers
     wb_subversion_provider.registerProvider()
 
@@ -89,38 +86,6 @@ def main( args ):
 
     return 0
 
-def initLocale():
-    # init the locale
-    if sys.platform == 'win32':
-        locale.setlocale( locale.LC_ALL, '' )
-
-    else:
-        if 'LC_ALL' in os.environ:
-            try:
-                locale.setlocale( locale.LC_ALL, os.environ['LC_ALL'] )
-                return
-            except locale.Error:
-                pass
-
-        language_code, encoding = locale.getdefaultlocale()
-        if language_code is None:
-            language_code = 'en_US'
-
-        if encoding is None:
-            encoding = 'UTF-8'
-        if encoding.lower() == 'utf':
-            encoding = 'UTF-8'
-
-        try:
-            # setlocale fails when params it does not understand are passed
-            locale.setlocale( locale.LC_ALL, '%s.%s' % (language_code, encoding) )
-        except locale.Error:
-            try:
-                # force a locale that will work
-                locale.setlocale( locale.LC_ALL, 'en_US.UTF-8' )
-            except locale.Error:
-                locale.setlocale( locale.LC_ALL, 'C' )
-
 # 
 # needed to make MEINC Installer notice these packages
 # Include all the codecs
