@@ -53,7 +53,11 @@ def EditFile( app, project_info, filename ):
     cur_dir = os.getcwd()
     try:
         wb_platform_specific.uChdir( project_info.getWorkingDir() )
-        os.system( command_line.encode( 'utf-8' ) )
+        output = __run_command_with_output( command_line.encode( 'utf-8' ) )
+        if len(output) > 0:
+            for line in output.split( '\n' ):
+                app.log.info( 'Edit command output: %r' % (line,) )
+
     finally:
         wb_platform_specific.uChdir( cur_dir )
 
@@ -191,7 +195,7 @@ def __sigchld_handler( signum, frame ):
         pass
 
 def _run_command( command_line ):
-    err_prefix = 'Error running %s' % command_line
+    err_prefix = 'Error running %s' % (command_line,)
 
     # install the sig child handler to get rid of the zomie processes
     global __sigchld_handler_installed
