@@ -12,6 +12,8 @@
 '''
 import os
 import types
+import threading
+import locale
 
 import pysvn
 import wx
@@ -514,6 +516,8 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
         if status.entry is None or status.entry.commit_time == 0:
             return ''
         else:
+            # should not need to force the locale!
+            locale.setlocale( locale.LC_ALL, self.app._setlocale_value )
             return wb_subversion_utils.fmtDateTime( status.entry.commit_time )
 
     def __get_LockCommentColumn( self, status ):
@@ -946,10 +950,7 @@ class SubversionListHandlerCommon(wb_list_panel_common.ListHandler):
     def Cmd_File_Info( self, all_rows ):
         for filename in [self.getFilename( row ) for row in all_rows]:
             try:
-                if hasattr( self.project_info.client_fg, 'info2' ):
-                    entry = self.project_info.client_fg.info2( filename, recurse=False )
-                else:
-                    entry = self.project_info.client_fg.info( filename )
+                entry = self.project_info.client_fg.info2( filename, recurse=False )
 
                 dialog = wb_subversion_info_dialog.InfoDialog( self.app,
                         self.list_panel.list_ctrl,
