@@ -276,7 +276,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
 
         try:
             self.need_upgrade = False
-            entry = self.client_fg.info( self.wc_path )
+            entry = self.client_fg.info2( self.wc_path, recurse=False )[0][1]
 
         except pysvn.ClientError, e:
             if wb_subversion_utils.version_info.has_upgrade:
@@ -287,7 +287,8 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
                     return
 
             # is it the  'is not a working copy' error?
-            if e.args[1][0][1] == pysvn.svn_err.wc_not_directory:
+            # of the 'Node not found' error?
+            if e.args[1][0][1] in (pysvn.svn_err.wc_not_directory, pysvn.svn_err.wc_path_not_found):
                 # need_checkout
                 return
 
@@ -297,7 +298,7 @@ class ProjectInfo(wb_source_control_providers.ProjectInfo):
         if entry is None:
             self.url = ''
         else:
-            self.url = entry.url
+            self.url = entry.URL
 
         self.all_files_status = self.client_fg.status( self.wc_path, recurse=p.view_recursive, ignore=False )
 
