@@ -500,10 +500,7 @@ class SubversionProject(wb_tree_panel.TreeProjectItem):
         filename = self.project_info.wc_path
 
         try:
-            if hasattr( self.project_info.client_fg, 'info2' ):
-                entry = self.project_info.client_fg.info2( filename, recurse=False )
-            else:
-                entry = self.project_info.client_fg.info( filename )
+            entry = self.project_info.client_fg.info2( filename, recurse=False )
 
             dialog = wb_subversion_info_dialog.InfoDialog( self.app,
                     self.app.frame.tree_panel.tree_ctrl,
